@@ -13,6 +13,16 @@ pub struct InteractionEvent {
     pub data: Vec<Seal>,
 }
 
+impl InteractionEvent {
+    pub fn new(previous_event_hash: SelfAddressingPrefix, data: Vec<Seal>)
+        -> Self {
+            InteractionEvent {
+                previous_event_hash,
+                data
+            }
+        }
+}
+
 impl EventSemantics for InteractionEvent {
     fn apply_to(&self, state: IdentifierState) -> Result<IdentifierState, Error> {
         Ok(IdentifierState { ..state })
