@@ -4,10 +4,9 @@ pub mod error;
 pub mod event;
 pub mod event_message;
 pub mod keri;
-pub mod log;
 pub mod prefix;
 pub mod processor;
 pub mod signer;
 pub mod state;
-
-pub(crate) mod keys;
+pub mod keys;
+pub mod event_parsing;
